# Changelog JuMonC


## [Unreleased]

## [0.4.2] - 2022-04-19
### Changed
- Fixed error in user plugin

## [0.4.1] - 2022-04-19
### Changed
- Fixed error in disk plugin when missing (the optional dependency) psutil
